==> bee-ui-0.0.28.tgz: package/src/Gallery/index.js <==

import React, {
  Component, PropTypes,
} from 'react';

import {
  Text, TouchableWithoutFeedback, View,
} from 'react-native';

import ReactNativeImageGallery from './react-native-image-gallery';

class Gallery extends Component {
  static defaultProps = {
    images: [],
  }

  static propTypes = {
    images: PropTypes.array,
  }

  set state(state) {
    if (state) {
      Object.keys(state).forEach((key) => {
        this[key] = state[key];
      });
    }
  }

  get images() {
    return this.props.images.map(image => ({ source: image }));
  }

  visible = false;

  show = () => {
    this.setState({
      visible: true,
    });
  }

  hide = () => {
    this.setState({
      visible: false,
    });
  }

  render() {
    const { visible, images, props, hide } = this;
    const { onSuccess, onCancel } = props;
    return visible && (
      <View style={{ position: 'absolute', top: 0, right: 0, bottom: 0, left: 0, backgroundColor: '#000' }}>
        <ReactNativeImageGallery
          images={images}
        />
        <TouchableWithoutFeedback onPress={onCancel || hide}>
          <View style={{ position: 'absolute', bottom: 10, left: 10, backgroundColor: 'rgba(0,0,0,.5)', padding: 4 }}>
            <Text style={{ color: '#fff' }}>取消</Text>
          </View>
        </TouchableWithoutFeedback>
        <TouchableWithoutFeedback onPress={onSuccess}>
          <View style={{ position: 'absolute', right: 10, bottom: 10, backgroundColor: 'rgba(0,0,0,.5)', padding: 4 }}>
            <Text style={{ color: '#fff' }}>保存</Text>
          </View>
        </TouchableWithoutFeedback>
      </View>
    );
  }
}

export default Gallery;

==> bee-ui-0.0.35.tgz: package/src/Gallery/index.js <==

import React, {
  Component, PropTypes,
} from 'react';

import {
  Text, TouchableWithoutFeedback, View,
} from 'react-native';

import ReactNativeImageGallery from './react-native-image-gallery';

class Gallery extends Component {
  static defaultProps = {
    images: [],
  }

  static propTypes = {
    images: PropTypes.node,
  }

  set state(state) {
    if (state) {
      Object.keys(state).forEach((key) => {
        this[key] = state[key];
      });
    }
  }

  get images() {
    return this.props.images.map(image => ({ source: image }));
  }

  visible = false;

  show = () => {
    this.setState({
      visible: true,
    });
  }

  hide = () => {
    this.setState({
      visible: false,
    });
  }

  render() {
    const { visible, images, props, hide } = this;
    const { onSuccess, onCancel } = props;
    return visible && (
      <View style={{ position: 'absolute', top: 0, right: 0, bottom: 0, left: 0, backgroundColor: '#000' }}>
        <ReactNativeImageGallery
          images={images}
        />
        <TouchableWithoutFeedback onPress={onCancel || hide}>
          <View style={{ position: 'absolute', bottom: 10, left: 10, backgroundColor: 'rgba(0,0,0,.5)', padding: 4 }}>
            <Text style={{ color: '#fff' }}>取消</Text>
          </View>
        </TouchableWithoutFeedback>
        <TouchableWithoutFeedback onPress={onSuccess}>
          <View style={{ position: 'absolute', right: 10, bottom: 10, backgroundColor: 'rgba(0,0,0,.5)', padding: 4 }}>
            <Text style={{ color: '#fff' }}>保存</Text>
          </View>
        </TouchableWithoutFeedback>
      </View>
    );
  }
}

export default Gallery;
